@@ -2,14 +2,17 @@ from __future__ import print_function
 import requests
 import argparse
 
+# handle ModuleNotFoundError python3 execution
 try:
     from cli_weather.airquality_data import *
     from cli_weather.weather_data import *
     from cli_weather.weather_forecast_data import *
+    from cli_weather.airquality_forecast_data import *
 except ModuleNotFoundError:
     from airquality_data import *
     from weather_data import *
     from weather_forecast_data import *
+    from airquality_forecast_data import *
 
 def get_by_postalcode_args(subparsers):
     postalcode_parser = subparsers.add_parser('postalcode',
@@ -42,7 +45,7 @@ def get_by_postalcode_args(subparsers):
     postalcode_parser.add_argument(
         "-u", "--units",
         choices=['M','S','F'],
-        help="M - [DEFAULT] Metric (Celcius, m/s, mm)\nS - Scientific (Kelvin, m/s, mm)\nI - Fahrenheit (F, mph, in)",
+        help="M - Metric (Celcius, m/s, mm) [DEFAULT]\nS - Scientific (Kelvin, m/s, mm)\nI - Fahrenheit (F, mph, in)",
         default="M"
     )
 
@@ -52,7 +55,7 @@ def postalcode_parse(args):
     units = args.units
     API_KEY = "2a7db0585e7541018229c17efb2efa94"
 
-    if args.airquality is True:
+    if args.airquality is True and args.forecast is False:
         if args.country == "":
             API_URL = "https://api.weatherbit.io/v2.0/current/airquality?postal_code="+postalcode+"&key="
         else:
@@ -64,6 +67,12 @@ def postalcode_parse(args):
         else:
             API_URL = "https://api.weatherbit.io/v2.0/forecast/daily?postal_code="+postalcode+country+"&key="
 
+    elif args.airquality is True and args.forecast is True:
+         if args.country == "":
+            API_URL = "https://api.weatherbit.io/v2.0/forecast/airquality?postal_code="+postalcode+"&key="
+         else:
+            API_URL = "https://api.weatherbit.io/v2.0/forecast/airquality?postal_code="+postalcode+country+"&key="
+
     elif args.airquality is False:
         if args.country == "":
             API_URL = "https://api.weatherbit.io/v2.0/current?postal_code="+postalcode+"&key="
@@ -104,8 +113,7 @@ def postalcode_parse(args):
         get_weather_forecast(main_data, degree, speed, distance)
         return
     elif args.airquality is True and args.detailed in choice and args.forecast is True:
-        # TODO: call airquality forecast function
-        pass
+        get_airquality_forecast(main_data)
         return
 
     # call arguments based on selected combination of optional arguments
@@ -120,3 +128,5 @@ def postalcode_parse(args):
 
     elif args.detailed is True and args.airquality is True:
         get_detailed_airquality(main_data)
+
+# changes to be made setup.py version to 0.1.5, units in weather data, readme 16days to 7 days.
\ No newline at end of file
